@@ -1,18 +1,18 @@
-/*  Arg_parser - POSIX/GNU command line argument parser. (C version)
-    Copyright (C) 2006-2019 Antonio Diaz Diaz.
+/* Arg_parser - POSIX/GNU command line argument parser. (C version)
+   Copyright (C) 2006-2020 Antonio Diaz Diaz.
 
-    This program is free software: you have unlimited permission to
-    copy, distribute and modify it.
+   This program is free software: you have unlimited permission to
+   copy, distribute, and modify it.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
 /*
-    Exit status: 0 for a normal exit, 1 for environmental problems
-    (file not found, invalid flags, I/O errors, etc), 2 to indicate a
-    corrupt or invalid input file, 3 for an internal consistency error
-    (eg, bug) which caused arg_parser to panic.
+   Exit status: 0 for a normal exit, 1 for environmental problems
+   (file not found, invalid flags, I/O errors, etc), 2 to indicate a
+   corrupt or invalid input file, 3 for an internal consistency error
+   (eg, bug) which caused arg_parser to panic.
 */
 
 #include <stdio.h>
@@ -23,8 +23,8 @@
 
 
 static const char * const program_name = "arg_parser";
-static const char * const program_year = "2019";
-static const char * invocation_name = 0;
+static const char * const program_year = "2020";
+static const char * invocation_name = "arg_parser";	/* default value */
 
 
 void show_help( const char verbose )
@@ -43,7 +43,7 @@ void show_help( const char verbose )
           "\nThe C++ version of Arg_parser can also parse options from configuration\n"
           "files.\n"
           "\nTo use Arg_parser in your own programs simply copy the files 'carg_parser.h'\n"
-          "and 'carg_parser.c' in your source tree. See also the file 'cmain.c' for an\n"
+          "and 'carg_parser.c' in your source tree. See the file 'cmain.c' for an\n"
           "example of use.\n"
           "\nUsage: %s [options]\n", invocation_name );
   printf( "\nOptions:\n"
@@ -129,7 +129,7 @@ int main( const int argc, const char * const argv[] )
 
   struct Arg_parser parser;
   int argind;
-  invocation_name = argv[0];
+  if( argc > 0 ) invocation_name = argv[0];
 
   if( !ap_init( &parser, argc, argv, options, 0 ) )
     { show_error( "Not enough memory.", 0, 0 ); return 1; }
