@@ -1,18 +1,18 @@
-/*  Arg_parser - POSIX/GNU command line argument parser. (C++ version)
-    Copyright (C) 2006-2019 Antonio Diaz Diaz.
+/* Arg_parser - POSIX/GNU command line argument parser. (C++ version)
+   Copyright (C) 2006-2020 Antonio Diaz Diaz.
 
-    This program is free software: you have unlimited permission to
-    copy, distribute and modify it.
+   This program is free software: you have unlimited permission to
+   copy, distribute, and modify it.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
 /*
-    Exit status: 0 for a normal exit, 1 for environmental problems
-    (file not found, invalid flags, I/O errors, etc), 2 to indicate a
-    corrupt or invalid input file, 3 for an internal consistency error
-    (eg, bug) which caused arg_parser to panic.
+   Exit status: 0 for a normal exit, 1 for environmental problems
+   (file not found, invalid flags, I/O errors, etc), 2 to indicate a
+   corrupt or invalid input file, 3 for an internal consistency error
+   (eg, bug) which caused arg_parser to panic.
 */
 
 #include <cstdio>
@@ -27,8 +27,8 @@
 namespace {
 
 const char * const program_name = "arg_parser";
-const char * const program_year = "2019";
-const char * invocation_name = 0;
+const char * const program_year = "2020";
+const char * invocation_name = program_name;		// default value
 
 
 void show_help( const bool verbose )
@@ -47,7 +47,7 @@ void show_help( const bool verbose )
                "\nThe C++ version of Arg_parser can also parse options from configuration\n"
                "files.\n"
                "\nTo use Arg_parser in your own programs simply copy the files 'arg_parser.h'\n"
-               "and 'arg_parser.cc' in your source tree. See also the file 'main.cc' for an\n"
+               "and 'arg_parser.cc' in your source tree. See the file 'main.cc' for an\n"
                "example of use.\n"
                "\nUsage: %s [options]\n", invocation_name );
   std::printf( "\nOptions:\n"
@@ -118,7 +118,7 @@ const char * optname( const int code, const Arg_parser::Option options[] )
 int main( const int argc, const char * const argv[] )
   {
   bool verbose = false;
-  invocation_name = argv[0];
+  if( argc > 0 ) invocation_name = argv[0];
 
   const Arg_parser::Option options[] =
     {
